@@ -10,9 +10,9 @@
 
 /*-----prototypes of functions defined here-----*/
 extern void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
-		   double d[], double e[], double vt[], long ldvt,
-		   double u[],long ldu, double c[], long ldc,
-		   double work[], long *info );
+                   double d[], double e[], double vt[], long ldvt,
+                   double u[],long ldu, double c[], long ldc,
+                   double work[], long *info );
 /*-----end of prototypes-----*/
 
 
@@ -23,20 +23,17 @@ extern double   dlamch( char cmach );
 
 extern void dlartg( double f, double g, double *cs, double *sn, double *r );
 extern void dlasv2( double f, double g, double h,
-		   double *ssmin, double *ssmax, double *snr,
-		   double *csr, double *snl, double *csl );
+                   double *ssmin, double *ssmax, double *snr,
+                   double *csr, double *snl, double *csl );
 extern void dlas2( double f, double g, double h,
-		  double *ssmin, double *ssmax );
+                  double *ssmin, double *ssmax );
 extern void dlasr( char side, char pivot, char direct, long m, long n,
-		  double c[], double s[], double a[], long lda );
+                  double c[], double s[], double a[], long lda );
 
 
 
 /*---blas routines---*/
-extern void  ydscal(long n,double da,double dx[],long incx);
-extern void  ydrot (long n,double dx[],long incx,double dy[],long incy,
-		   double c,double s);
-extern void  ydswap (long n,double dx[],long incx,double dy[],long incy);
+/* dscal dswap drot */
 
 
 
@@ -61,9 +58,9 @@ extern double sqrt(double);
 
 
 void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
-	    double d[], double e[], double vt[], long ldvt,
-	    double u[],long ldu, double c[], long ldc,
-	    double work[], long *info )
+            double d[], double e[], double vt[], long ldvt,
+            double u[],long ldu, double c[], long ldc,
+            double work[], long *info )
 {
   /**
    *  -- LAPACK routine (version 1.1) --
@@ -250,12 +247,12 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
   } else if( ncc<0 ) {
     *info = -5;
   } else if( ( ncvt==0 && ldvt<1 ) ||
-	    ( ncvt>0 && ldvt<max( 1, n ) ) ) {
+            ( ncvt>0 && ldvt<max( 1, n ) ) ) {
     *info = -9;
   } else if( ldu<max( 1, nru ) ) {
     *info = -11;
   } else if( ( ncc==0 && ldc<1 ) ||
-	    ( ncc>0 && ldc<max( 1, n ) ) ) {
+            ( ncc>0 && ldc<max( 1, n ) ) ) {
     *info = -13;
   }
   if( *info!=0 ) {
@@ -291,8 +288,8 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
       e_1( i ) = sn*d_1( i+1 );
       d_1( i+1 ) = cs*d_1( i+1 );
       if( rotate ) {
-	work_1( i ) = cs;
-	work_1( nm1+i ) = sn;
+        work_1( i ) = cs;
+        work_1( nm1+i ) = sn;
       }
     }
     /**
@@ -300,10 +297,10 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
      **/
     if( nru>0 )
       dlasr( 'r', 'v', 'f', nru, n, &work_1( 1 ), &work_1( n ), u,
-	    ldu );
+            ldu );
     if( ncc>0 )
       dlasr( 'l', 'v', 'f', n, ncc, &work_1( 1 ), &work_1( n ), c,
-	    ldc );
+            ldc );
   }
   /**
    *     Compute approximate maximum, minimum singular values
@@ -322,7 +319,7 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
       mu = abs( d_1( i ) )*( mu / ( mu+abs( e_1( i-1 ) ) ) );
       sminoa = min( sminoa, mu );
       if( sminoa==zero )
-	goto L_40;
+        goto L_40;
     }
   L_40:
     sminoa = sminoa / sqrt( dble( n ) );
@@ -413,7 +410,7 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
      *        2 by 2 block, handle separately
      **/
     dlasv2( d_1( m-1 ), e_1( m-1 ), d_1( m ), &sigmn, &sigmx, &sinr,
-	   &cosr, &sinl, &cosl );
+           &cosr, &sinl, &cosl );
     d_1( m-1 ) = sigmx;
     e_1( m-1 ) = zero;
     d_1( m ) = sigmn;
@@ -421,13 +418,13 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
      *        Compute singular vectors, if desired
      **/
     if( ncvt>0 )
-      ydrot( ncvt, &vt_2( m-1, 1 ), ldvt, &vt_2( m, 1 ), ldvt, cosr,
-	   sinr );
+      cblas_drot( ncvt, &vt_2( m-1, 1 ), ldvt, &vt_2( m, 1 ), ldvt, cosr,
+           sinr );
     if( nru>0 )
-      ydrot( nru, &u_2( 1, m-1 ), 1, &u_2( 1, m ), 1, cosl, sinl );
+      cblas_drot( nru, &u_2( 1, m-1 ), 1, &u_2( 1, m ), 1, cosl, sinl );
     if( ncc>0 )
-      ydrot( ncc, &c_2( m-1, 1 ), ldc, &c_2( m, 1 ), ldc, cosl,
-	   sinl );
+      cblas_drot( ncc, &c_2( m-1, 1 ), ldc, &c_2( m, 1 ), ldc, cosl,
+           sinl );
     m = m - 2;
     goto L_50;
   }
@@ -470,30 +467,30 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
       mu = abs( d_1( ll ) );
       sminl = mu;
       for (lll=ll ; lll<=m - 1 ; lll+=1) {
-	if( abs( e_1( lll ) )<=tol*mu ) {
-	  e_1( lll ) = zero;
-	  goto L_50;
-	}
-	sminlo = sminl;
-	mu = abs( d_1( lll+1 ) )*( mu / ( mu+abs( e_1( lll ) ) ) );
-	sminl = min( sminl, mu );
+        if( abs( e_1( lll ) )<=tol*mu ) {
+          e_1( lll ) = zero;
+          goto L_50;
+        }
+        sminlo = sminl;
+        mu = abs( d_1( lll+1 ) )*( mu / ( mu+abs( e_1( lll ) ) ) );
+        sminl = min( sminl, mu );
       }
       /**
        *           If singular values only wanted, apply gap test to bottom
        *           end of matrix
        **/
       if( job==0 ) {
-	gap = sminlo / sqrt( dble( m-ll ) ) - abs( d_1( m ) );
-	if( gap>zero ) {
-	  abss = abs( d_1( m ) );
-	  abse = abs( e_1( m-1 ) );
-	  gmax = max( gap, max(abss, abse) );
-	  if( ( abse / gmax )*( abse / gmax )<=tol*( gap / gmax )*
-	     ( abss / gmax ) ) {
-	    e_1( m-1 ) = zero;
-	    goto L_50;
-	  }
-	}
+        gap = sminlo / sqrt( dble( m-ll ) ) - abs( d_1( m ) );
+        if( gap>zero ) {
+          abss = abs( d_1( m ) );
+          abse = abs( e_1( m-1 ) );
+          gmax = max( gap, max(abss, abse) );
+          if( ( abse / gmax )*( abse / gmax )<=tol*( gap / gmax )*
+             ( abss / gmax ) ) {
+            e_1( m-1 ) = zero;
+            goto L_50;
+          }
+        }
       }
     }
   } else {
@@ -515,30 +512,30 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
       mu = abs( d_1( m ) );
       sminl = mu;
       for (lll=m - 1 ; lll>=ll ; lll+=-1) {
-	if( abs( e_1( lll ) )<=tol*mu ) {
-	  e_1( lll ) = zero;
-	  goto L_50;
-	}
-	sminlo = sminl;
-	mu = abs( d_1( lll ) )*( mu / ( mu+abs( e_1( lll ) ) ) );
-	sminl = min( sminl, mu );
+        if( abs( e_1( lll ) )<=tol*mu ) {
+          e_1( lll ) = zero;
+          goto L_50;
+        }
+        sminlo = sminl;
+        mu = abs( d_1( lll ) )*( mu / ( mu+abs( e_1( lll ) ) ) );
+        sminl = min( sminl, mu );
       }
       /**
        *           If singular values only wanted, apply gap test to top
        *           end of matrix
        **/
       if( job==0 ) {
-	gap = sminlo / sqrt( dble( m-ll ) ) - abs( d_1( ll ) );
-	if( gap>zero ) {
-	  abss = abs( d_1( ll ) );
-	  abse = abs( e_1( ll ) );
-	  gmax = max( gap, max(abss, abse) );
-	  if( ( abse / gmax )*( abse / gmax )<=tol*( gap / gmax )*
-	     ( abss / gmax ) ) {
-	    e_1( ll ) = zero;
-	    goto L_50;
-	  }
-	}
+        gap = sminlo / sqrt( dble( m-ll ) ) - abs( d_1( ll ) );
+        if( gap>zero ) {
+          abss = abs( d_1( ll ) );
+          abse = abs( e_1( ll ) );
+          gmax = max( gap, max(abss, abse) );
+          if( ( abse / gmax )*( abse / gmax )<=tol*( gap / gmax )*
+             ( abss / gmax ) ) {
+            e_1( ll ) = zero;
+            goto L_50;
+          }
+        }
       }
     }
   }
@@ -570,7 +567,7 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
      **/
     if( sll>zero ) {
       if( ( shift / sll )*( shift / sll )<eps )
-	shift = zero;
+        shift = zero;
     }
   }
   /**
@@ -592,64 +589,64 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
        **/
       if( rotate ) {
 
-	dlartg( d_1( ll )*cs, e_1( ll ), &cs, &sn, &r );
-	dlartg( oldcs*r, d_1( ll+1 )*sn, &oldcs, &oldsn,
-	       &d_1( ll ) );
-	work_1( 1 ) = cs;
-	work_1( 1+nm1 ) = sn;
-	work_1( 1+nm12 ) = oldcs;
-	work_1( 1+nm13 ) = oldsn;
-	irot = 1;
-	for (i=ll + 1 ; i<=m - 1 ; i+=1) {
-	  dlartg( d_1( i )*cs, e_1( i ), &cs, &sn, &r );
-	  e_1( i-1 ) = oldsn*r;
-	  dlartg( oldcs*r, d_1( i+1 )*sn, &oldcs, &oldsn,
-		 &d_1( i ) );
-	  irot = irot + 1;
-	  work_1( irot ) = cs;
-	  work_1( irot+nm1 ) = sn;
-	  work_1( irot+nm12 ) = oldcs;
-	  work_1( irot+nm13 ) = oldsn;
-	}
-	h = d_1( m )*cs;
-	d_1( m ) = h*oldcs;
-	e_1( m-1 ) = h*oldsn;
-	/**
-	 *              Update singular vectors
-	 **/
-	if( ncvt>0 )
-	  dlasr( 'l', 'v', 'f', m-ll+1, ncvt, &work_1( 1 ),
-		&work_1( n ), &vt_2( ll, 1 ), ldvt );
-	if( nru>0 )
-	  dlasr( 'r', 'v', 'f', nru, m-ll+1,
-		&work_1( nm12+1 ), &work_1( nm13+1 ),
-		&u_2( 1, ll ), ldu );
-	if( ncc>0 )
-	  dlasr( 'l', 'v', 'f', m-ll+1, ncc,
-		&work_1( nm12+1 ), &work_1( nm13+1 ),
-		&c_2( ll, 1 ), ldc );
+        dlartg( d_1( ll )*cs, e_1( ll ), &cs, &sn, &r );
+        dlartg( oldcs*r, d_1( ll+1 )*sn, &oldcs, &oldsn,
+               &d_1( ll ) );
+        work_1( 1 ) = cs;
+        work_1( 1+nm1 ) = sn;
+        work_1( 1+nm12 ) = oldcs;
+        work_1( 1+nm13 ) = oldsn;
+        irot = 1;
+        for (i=ll + 1 ; i<=m - 1 ; i+=1) {
+          dlartg( d_1( i )*cs, e_1( i ), &cs, &sn, &r );
+          e_1( i-1 ) = oldsn*r;
+          dlartg( oldcs*r, d_1( i+1 )*sn, &oldcs, &oldsn,
+                 &d_1( i ) );
+          irot = irot + 1;
+          work_1( irot ) = cs;
+          work_1( irot+nm1 ) = sn;
+          work_1( irot+nm12 ) = oldcs;
+          work_1( irot+nm13 ) = oldsn;
+        }
+        h = d_1( m )*cs;
+        d_1( m ) = h*oldcs;
+        e_1( m-1 ) = h*oldsn;
+        /**
+         *              Update singular vectors
+         **/
+        if( ncvt>0 )
+          dlasr( 'l', 'v', 'f', m-ll+1, ncvt, &work_1( 1 ),
+                &work_1( n ), &vt_2( ll, 1 ), ldvt );
+        if( nru>0 )
+          dlasr( 'r', 'v', 'f', nru, m-ll+1,
+                &work_1( nm12+1 ), &work_1( nm13+1 ),
+                &u_2( 1, ll ), ldu );
+        if( ncc>0 )
+          dlasr( 'l', 'v', 'f', m-ll+1, ncc,
+                &work_1( nm12+1 ), &work_1( nm13+1 ),
+                &c_2( ll, 1 ), ldc );
 
       } else {
 
-	dlartg( d_1( ll )*cs, e_1( ll ), &cs, &sn, &r );
-	dlartg( oldcs*r, d_1( ll+1 )*sn, &oldcs, &oldsn,
-	       &d_1( ll ) );
-	for (i=ll + 1 ; i<=m - 1 ; i+=1) {
-	  dlartg( d_1( i )*cs, e_1( i ), &cs, &sn, &r );
-	  e_1( i-1 ) = oldsn*r;
-	  dlartg( oldcs*r, d_1( i+1 )*sn, &oldcs, &oldsn,
-		 &d_1( i ) );
-	}
-	h = d_1( m )*cs;
-	d_1( m ) = h*oldcs;
-	e_1( m-1 ) = h*oldsn;
+        dlartg( d_1( ll )*cs, e_1( ll ), &cs, &sn, &r );
+        dlartg( oldcs*r, d_1( ll+1 )*sn, &oldcs, &oldsn,
+               &d_1( ll ) );
+        for (i=ll + 1 ; i<=m - 1 ; i+=1) {
+          dlartg( d_1( i )*cs, e_1( i ), &cs, &sn, &r );
+          e_1( i-1 ) = oldsn*r;
+          dlartg( oldcs*r, d_1( i+1 )*sn, &oldcs, &oldsn,
+                 &d_1( i ) );
+        }
+        h = d_1( m )*cs;
+        d_1( m ) = h*oldcs;
+        e_1( m-1 ) = h*oldsn;
 
       }
       /**
        *           Test convergence
        **/
       if( abs( e_1( m-1 ) )<=thresh )
-	e_1( m-1 ) = zero;
+        e_1( m-1 ) = zero;
 
     } else {
       /**
@@ -662,61 +659,61 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
        **/
       if( rotate ) {
 
-	dlartg( d_1( m )*cs, e_1( m-1 ), &cs, &sn, &r );
-	dlartg( oldcs*r, d_1( m-1 )*sn, &oldcs, &oldsn, &d_1( m ) );
-	work_1( m-ll ) = cs;
-	work_1( m-ll+nm1 ) = -sn;
-	work_1( m-ll+nm12 ) = oldcs;
-	work_1( m-ll+nm13 ) = -oldsn;
-	irot = m - ll;
-	for (i=m - 1 ; i>=ll + 1 ; i+=-1) {
-	  dlartg( d_1( i )*cs, e_1( i-1 ), &cs, &sn, &r );
-	  e_1( i ) = oldsn*r;
-	  dlartg( oldcs*r, d_1( i-1 )*sn, &oldcs, &oldsn,
-		 &d_1( i ) );
-	  irot = irot - 1;
-	  work_1( irot ) = cs;
-	  work_1( irot+nm1 ) = -sn;
-	  work_1( irot+nm12 ) = oldcs;
-	  work_1( irot+nm13 ) = -oldsn;
-	}
-	h = d_1( ll )*cs;
-	d_1( ll ) = h*oldcs;
-	e_1( ll ) = h*oldsn;
-	/**
-	 *              Update singular vectors
-	 **/
-	if( ncvt>0 )
-	  dlasr( 'l', 'v', 'b', m-ll+1, ncvt,
-		&work_1( nm12+1 ), &work_1( nm13+1 ),
-		&vt_2( ll, 1 ), ldvt );
-	if( nru>0 )
-	  dlasr( 'r', 'v', 'b', nru, m-ll+1, &work_1( 1 ),
-		&work_1( n ), &u_2( 1, ll ), ldu );
-	if( ncc>0 )
-	  dlasr( 'l', 'v', 'b', m-ll+1, ncc, &work_1( 1 ),
-		&work_1( n ), &c_2( ll, 1 ), ldc );
+        dlartg( d_1( m )*cs, e_1( m-1 ), &cs, &sn, &r );
+        dlartg( oldcs*r, d_1( m-1 )*sn, &oldcs, &oldsn, &d_1( m ) );
+        work_1( m-ll ) = cs;
+        work_1( m-ll+nm1 ) = -sn;
+        work_1( m-ll+nm12 ) = oldcs;
+        work_1( m-ll+nm13 ) = -oldsn;
+        irot = m - ll;
+        for (i=m - 1 ; i>=ll + 1 ; i+=-1) {
+          dlartg( d_1( i )*cs, e_1( i-1 ), &cs, &sn, &r );
+          e_1( i ) = oldsn*r;
+          dlartg( oldcs*r, d_1( i-1 )*sn, &oldcs, &oldsn,
+                 &d_1( i ) );
+          irot = irot - 1;
+          work_1( irot ) = cs;
+          work_1( irot+nm1 ) = -sn;
+          work_1( irot+nm12 ) = oldcs;
+          work_1( irot+nm13 ) = -oldsn;
+        }
+        h = d_1( ll )*cs;
+        d_1( ll ) = h*oldcs;
+        e_1( ll ) = h*oldsn;
+        /**
+         *              Update singular vectors
+         **/
+        if( ncvt>0 )
+          dlasr( 'l', 'v', 'b', m-ll+1, ncvt,
+                &work_1( nm12+1 ), &work_1( nm13+1 ),
+                &vt_2( ll, 1 ), ldvt );
+        if( nru>0 )
+          dlasr( 'r', 'v', 'b', nru, m-ll+1, &work_1( 1 ),
+                &work_1( n ), &u_2( 1, ll ), ldu );
+        if( ncc>0 )
+          dlasr( 'l', 'v', 'b', m-ll+1, ncc, &work_1( 1 ),
+                &work_1( n ), &c_2( ll, 1 ), ldc );
 
       } else {
 
-	dlartg( d_1( m )*cs, e_1( m-1 ), &cs, &sn, &r );
-	dlartg( oldcs*r, d_1( m-1 )*sn, &oldcs, &oldsn, &d_1( m ) );
-	for (i=m - 1 ; i>=ll + 1 ; i+=-1) {
-	  dlartg( d_1( i )*cs, e_1( i-1 ), &cs, &sn, &r );
-	  e_1( i ) = oldsn*r;
-	  dlartg( oldcs*r, d_1( i-1 )*sn, &oldcs, &oldsn,
-		 &d_1( i ) );
-	}
-	h = d_1( ll )*cs;
-	d_1( ll ) = h*oldcs;
-	e_1( ll ) = h*oldsn;
+        dlartg( d_1( m )*cs, e_1( m-1 ), &cs, &sn, &r );
+        dlartg( oldcs*r, d_1( m-1 )*sn, &oldcs, &oldsn, &d_1( m ) );
+        for (i=m - 1 ; i>=ll + 1 ; i+=-1) {
+          dlartg( d_1( i )*cs, e_1( i-1 ), &cs, &sn, &r );
+          e_1( i ) = oldsn*r;
+          dlartg( oldcs*r, d_1( i-1 )*sn, &oldcs, &oldsn,
+                 &d_1( i ) );
+        }
+        h = d_1( ll )*cs;
+        d_1( ll ) = h*oldcs;
+        e_1( ll ) = h*oldsn;
 
       }
       /**
        *           Test convergence
        **/
       if( abs( e_1( ll ) )<=thresh )
-	e_1( ll ) = zero;
+        e_1( ll ) = zero;
     }
   } else {
     /**
@@ -727,246 +724,246 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
        *           Chase bulge from top to bottom
        **/
       f = ( abs( d_1( ll ) )-shift )*
-	( sign( one, d_1( ll ) )+shift / d_1( ll ) );
+        ( sign( one, d_1( ll ) )+shift / d_1( ll ) );
       g = e_1( ll );
       /**
        *           Save cosines and sines if singular vectors desired
        **/
       if( rotate ) {
 
-	dlartg( f, g, &cosr, &sinr, &r );
-	f = cosr*d_1( ll ) + sinr*e_1( ll );
-	e_1( ll ) = cosr*e_1( ll ) - sinr*d_1( ll );
-	g = sinr*d_1( ll+1 );
-	d_1( ll+1 ) = cosr*d_1( ll+1 );
-	dlartg( f, g, &cosl, &sinl, &r );
-	d_1( ll ) = r;
-	f = cosl*e_1( ll ) + sinl*d_1( ll+1 );
-	d_1( ll+1 ) = cosl*d_1( ll+1 ) - sinl*e_1( ll );
-	g = sinl*e_1( ll+1 );
-	e_1( ll+1 ) = cosl*e_1( ll+1 );
-	work_1( 1 ) = cosr;
-	work_1( 1+nm1 ) = sinr;
-	work_1( 1+nm12 ) = cosl;
-	work_1( 1+nm13 ) = sinl;
-	irot = 1;
-	for (i=ll + 1 ; i<=m - 2 ; i+=1) {
-	  dlartg( f, g, &cosr, &sinr, &r );
-	  e_1( i-1 ) = r;
-	  f = cosr*d_1( i ) + sinr*e_1( i );
-	  e_1( i ) = cosr*e_1( i ) - sinr*d_1( i );
-	  g = sinr*d_1( i+1 );
-	  d_1( i+1 ) = cosr*d_1( i+1 );
-	  dlartg( f, g, &cosl, &sinl, &r );
-	  d_1( i ) = r;
-	  f = cosl*e_1( i ) + sinl*d_1( i+1 );
-	  d_1( i+1 ) = cosl*d_1( i+1 ) - sinl*e_1( i );
-	  g = sinl*e_1( i+1 );
-	  e_1( i+1 ) = cosl*e_1( i+1 );
-	  irot = irot + 1;
-	  work_1( irot ) = cosr;
-	  work_1( irot+nm1 ) = sinr;
-	  work_1( irot+nm12 ) = cosl;
-	  work_1( irot+nm13 ) = sinl;
-	}
-	dlartg( f, g, &cosr, &sinr, &r );
-	e_1( m-2 ) = r;
-	f = cosr*d_1( m-1 ) + sinr*e_1( m-1 );
-	e_1( m-1 ) = cosr*e_1( m-1 ) - sinr*d_1( m-1 );
-	g = sinr*d_1( m );
-	d_1( m ) = cosr*d_1( m );
-	dlartg( f, g, &cosl, &sinl, &r );
-	d_1( m-1 ) = r;
-	f = cosl*e_1( m-1 ) + sinl*d_1( m );
-	d_1( m ) = cosl*d_1( m ) - sinl*e_1( m-1 );
-	irot = irot + 1;
-	work_1( irot ) = cosr;
-	work_1( irot+nm1 ) = sinr;
-	work_1( irot+nm12 ) = cosl;
-	work_1( irot+nm13 ) = sinl;
-	e_1( m-1 ) = f;
-	/**
-	 *              Update singular vectors
-	 **/
-	if( ncvt>0 )
-	  dlasr( 'l', 'v', 'f', m-ll+1, ncvt, &work_1( 1 ),
-		&work_1( n ), &vt_2( ll, 1 ), ldvt );
-	if( nru>0 )
-	  dlasr( 'r', 'v', 'f', nru, m-ll+1,
-		&work_1( nm12+1 ), &work_1( nm13+1 ),
-		&u_2( 1, ll ), ldu );
-	if( ncc>0 )
-	  dlasr( 'l', 'v', 'f', m-ll+1, ncc,
-		&work_1( nm12+1 ), &work_1( nm13+1 ),
-		&c_2( ll, 1 ), ldc );
+        dlartg( f, g, &cosr, &sinr, &r );
+        f = cosr*d_1( ll ) + sinr*e_1( ll );
+        e_1( ll ) = cosr*e_1( ll ) - sinr*d_1( ll );
+        g = sinr*d_1( ll+1 );
+        d_1( ll+1 ) = cosr*d_1( ll+1 );
+        dlartg( f, g, &cosl, &sinl, &r );
+        d_1( ll ) = r;
+        f = cosl*e_1( ll ) + sinl*d_1( ll+1 );
+        d_1( ll+1 ) = cosl*d_1( ll+1 ) - sinl*e_1( ll );
+        g = sinl*e_1( ll+1 );
+        e_1( ll+1 ) = cosl*e_1( ll+1 );
+        work_1( 1 ) = cosr;
+        work_1( 1+nm1 ) = sinr;
+        work_1( 1+nm12 ) = cosl;
+        work_1( 1+nm13 ) = sinl;
+        irot = 1;
+        for (i=ll + 1 ; i<=m - 2 ; i+=1) {
+          dlartg( f, g, &cosr, &sinr, &r );
+          e_1( i-1 ) = r;
+          f = cosr*d_1( i ) + sinr*e_1( i );
+          e_1( i ) = cosr*e_1( i ) - sinr*d_1( i );
+          g = sinr*d_1( i+1 );
+          d_1( i+1 ) = cosr*d_1( i+1 );
+          dlartg( f, g, &cosl, &sinl, &r );
+          d_1( i ) = r;
+          f = cosl*e_1( i ) + sinl*d_1( i+1 );
+          d_1( i+1 ) = cosl*d_1( i+1 ) - sinl*e_1( i );
+          g = sinl*e_1( i+1 );
+          e_1( i+1 ) = cosl*e_1( i+1 );
+          irot = irot + 1;
+          work_1( irot ) = cosr;
+          work_1( irot+nm1 ) = sinr;
+          work_1( irot+nm12 ) = cosl;
+          work_1( irot+nm13 ) = sinl;
+        }
+        dlartg( f, g, &cosr, &sinr, &r );
+        e_1( m-2 ) = r;
+        f = cosr*d_1( m-1 ) + sinr*e_1( m-1 );
+        e_1( m-1 ) = cosr*e_1( m-1 ) - sinr*d_1( m-1 );
+        g = sinr*d_1( m );
+        d_1( m ) = cosr*d_1( m );
+        dlartg( f, g, &cosl, &sinl, &r );
+        d_1( m-1 ) = r;
+        f = cosl*e_1( m-1 ) + sinl*d_1( m );
+        d_1( m ) = cosl*d_1( m ) - sinl*e_1( m-1 );
+        irot = irot + 1;
+        work_1( irot ) = cosr;
+        work_1( irot+nm1 ) = sinr;
+        work_1( irot+nm12 ) = cosl;
+        work_1( irot+nm13 ) = sinl;
+        e_1( m-1 ) = f;
+        /**
+         *              Update singular vectors
+         **/
+        if( ncvt>0 )
+          dlasr( 'l', 'v', 'f', m-ll+1, ncvt, &work_1( 1 ),
+                &work_1( n ), &vt_2( ll, 1 ), ldvt );
+        if( nru>0 )
+          dlasr( 'r', 'v', 'f', nru, m-ll+1,
+                &work_1( nm12+1 ), &work_1( nm13+1 ),
+                &u_2( 1, ll ), ldu );
+        if( ncc>0 )
+          dlasr( 'l', 'v', 'f', m-ll+1, ncc,
+                &work_1( nm12+1 ), &work_1( nm13+1 ),
+                &c_2( ll, 1 ), ldc );
 
       } else {
 
-	dlartg( f, g, &cosr, &sinr, &r );
-	f = cosr*d_1( ll ) + sinr*e_1( ll );
-	e_1( ll ) = cosr*e_1( ll ) - sinr*d_1( ll );
-	g = sinr*d_1( ll+1 );
-	d_1( ll+1 ) = cosr*d_1( ll+1 );
-	dlartg( f, g, &cosl, &sinl, &r );
-	d_1( ll ) = r;
-	f = cosl*e_1( ll ) + sinl*d_1( ll+1 );
-	d_1( ll+1 ) = cosl*d_1( ll+1 ) - sinl*e_1( ll );
-	g = sinl*e_1( ll+1 );
-	e_1( ll+1 ) = cosl*e_1( ll+1 );
-	for (i=ll + 1 ; i<=m - 2 ; i+=1) {
-	  dlartg( f, g, &cosr, &sinr, &r );
-	  e_1( i-1 ) = r;
-	  f = cosr*d_1( i ) + sinr*e_1( i );
-	  e_1( i ) = cosr*e_1( i ) - sinr*d_1( i );
-	  g = sinr*d_1( i+1 );
-	  d_1( i+1 ) = cosr*d_1( i+1 );
-	  dlartg( f, g, &cosl, &sinl, &r );
-	  d_1( i ) = r;
-	  f = cosl*e_1( i ) + sinl*d_1( i+1 );
-	  d_1( i+1 ) = cosl*d_1( i+1 ) - sinl*e_1( i );
-	  g = sinl*e_1( i+1 );
-	  e_1( i+1 ) = cosl*e_1( i+1 );
-	}
-	dlartg( f, g, &cosr, &sinr, &r );
-	e_1( m-2 ) = r;
-	f = cosr*d_1( m-1 ) + sinr*e_1( m-1 );
-	e_1( m-1 ) = cosr*e_1( m-1 ) - sinr*d_1( m-1 );
-	g = sinr*d_1( m );
-	d_1( m ) = cosr*d_1( m );
-	dlartg( f, g, &cosl, &sinl, &r );
-	d_1( m-1 ) = r;
-	f = cosl*e_1( m-1 ) + sinl*d_1( m );
-	d_1( m ) = cosl*d_1( m ) - sinl*e_1( m-1 );
-	e_1( m-1 ) = f;
+        dlartg( f, g, &cosr, &sinr, &r );
+        f = cosr*d_1( ll ) + sinr*e_1( ll );
+        e_1( ll ) = cosr*e_1( ll ) - sinr*d_1( ll );
+        g = sinr*d_1( ll+1 );
+        d_1( ll+1 ) = cosr*d_1( ll+1 );
+        dlartg( f, g, &cosl, &sinl, &r );
+        d_1( ll ) = r;
+        f = cosl*e_1( ll ) + sinl*d_1( ll+1 );
+        d_1( ll+1 ) = cosl*d_1( ll+1 ) - sinl*e_1( ll );
+        g = sinl*e_1( ll+1 );
+        e_1( ll+1 ) = cosl*e_1( ll+1 );
+        for (i=ll + 1 ; i<=m - 2 ; i+=1) {
+          dlartg( f, g, &cosr, &sinr, &r );
+          e_1( i-1 ) = r;
+          f = cosr*d_1( i ) + sinr*e_1( i );
+          e_1( i ) = cosr*e_1( i ) - sinr*d_1( i );
+          g = sinr*d_1( i+1 );
+          d_1( i+1 ) = cosr*d_1( i+1 );
+          dlartg( f, g, &cosl, &sinl, &r );
+          d_1( i ) = r;
+          f = cosl*e_1( i ) + sinl*d_1( i+1 );
+          d_1( i+1 ) = cosl*d_1( i+1 ) - sinl*e_1( i );
+          g = sinl*e_1( i+1 );
+          e_1( i+1 ) = cosl*e_1( i+1 );
+        }
+        dlartg( f, g, &cosr, &sinr, &r );
+        e_1( m-2 ) = r;
+        f = cosr*d_1( m-1 ) + sinr*e_1( m-1 );
+        e_1( m-1 ) = cosr*e_1( m-1 ) - sinr*d_1( m-1 );
+        g = sinr*d_1( m );
+        d_1( m ) = cosr*d_1( m );
+        dlartg( f, g, &cosl, &sinl, &r );
+        d_1( m-1 ) = r;
+        f = cosl*e_1( m-1 ) + sinl*d_1( m );
+        d_1( m ) = cosl*d_1( m ) - sinl*e_1( m-1 );
+        e_1( m-1 ) = f;
 
       }
       /**
        *           Test convergence
        **/
       if( abs( e_1( m-1 ) )<=thresh )
-	e_1( m-1 ) = zero;
+        e_1( m-1 ) = zero;
 
     } else {
       /**
        *           Chase bulge from bottom to top
        **/
       f = ( abs( d_1( m ) )-shift )*( sign( one, d_1( m ) )+shift /
-				     d_1( m ) );
+                                     d_1( m ) );
       g = e_1( m-1 );
       /**
        *           Save cosines and sines if singular vectors desired
        **/
       if( rotate ) {
 
-	dlartg( f, g, &cosr, &sinr, &r );
-	f = cosr*d_1( m ) + sinr*e_1( m-1 );
-	e_1( m-1 ) = cosr*e_1( m-1 ) - sinr*d_1( m );
-	g = sinr*d_1( m-1 );
-	d_1( m-1 ) = cosr*d_1( m-1 );
-	dlartg( f, g, &cosl, &sinl, &r );
-	d_1( m ) = r;
-	f = cosl*e_1( m-1 ) + sinl*d_1( m-1 );
-	d_1( m-1 ) = cosl*d_1( m-1 ) - sinl*e_1( m-1 );
-	g = sinl*e_1( m-2 );
-	e_1( m-2 ) = cosl*e_1( m-2 );
-	work_1( m-ll ) = cosr;
-	work_1( m-ll+nm1 ) = -sinr;
-	work_1( m-ll+nm12 ) = cosl;
-	work_1( m-ll+nm13 ) = -sinl;
-	irot = m - ll;
-	for (i=m - 1 ; i>=ll + 2 ; i+=-1) {
-	  dlartg( f, g, &cosr, &sinr, &r );
-	  e_1( i ) = r;
-	  f = cosr*d_1( i ) + sinr*e_1( i-1 );
-	  e_1( i-1 ) = cosr*e_1( i-1 ) - sinr*d_1( i );
-	  g = sinr*d_1( i-1 );
-	  d_1( i-1 ) = cosr*d_1( i-1 );
-	  dlartg( f, g, &cosl, &sinl, &r );
-	  d_1( i ) = r;
-	  f = cosl*e_1( i-1 ) + sinl*d_1( i-1 );
-	  d_1( i-1 ) = cosl*d_1( i-1 ) - sinl*e_1( i-1 );
-	  g = sinl*e_1( i-2 );
-	  e_1( i-2 ) = cosl*e_1( i-2 );
-	  irot = irot - 1;
-	  work_1( irot ) = cosr;
-	  work_1( irot+nm1 ) = -sinr;
-	  work_1( irot+nm12 ) = cosl;
-	  work_1( irot+nm13 ) = -sinl;
-	}
-	dlartg( f, g, &cosr, &sinr, &r );
-	e_1( ll+1 ) = r;
-	f = cosr*d_1( ll+1 ) + sinr*e_1( ll );
-	e_1( ll ) = cosr*e_1( ll ) - sinr*d_1( ll+1 );
-	g = sinr*d_1( ll );
-	d_1( ll ) = cosr*d_1( ll );
-	dlartg( f, g, &cosl, &sinl, &r );
-	d_1( ll+1 ) = r;
-	f = cosl*e_1( ll ) + sinl*d_1( ll );
-	d_1( ll ) = cosl*d_1( ll ) - sinl*e_1( ll );
-	irot = irot - 1;
-	work_1( irot ) = cosr;
-	work_1( irot+nm1 ) = -sinr;
-	work_1( irot+nm12 ) = cosl;
-	work_1( irot+nm13 ) = -sinl;
-	e_1( ll ) = f;
+        dlartg( f, g, &cosr, &sinr, &r );
+        f = cosr*d_1( m ) + sinr*e_1( m-1 );
+        e_1( m-1 ) = cosr*e_1( m-1 ) - sinr*d_1( m );
+        g = sinr*d_1( m-1 );
+        d_1( m-1 ) = cosr*d_1( m-1 );
+        dlartg( f, g, &cosl, &sinl, &r );
+        d_1( m ) = r;
+        f = cosl*e_1( m-1 ) + sinl*d_1( m-1 );
+        d_1( m-1 ) = cosl*d_1( m-1 ) - sinl*e_1( m-1 );
+        g = sinl*e_1( m-2 );
+        e_1( m-2 ) = cosl*e_1( m-2 );
+        work_1( m-ll ) = cosr;
+        work_1( m-ll+nm1 ) = -sinr;
+        work_1( m-ll+nm12 ) = cosl;
+        work_1( m-ll+nm13 ) = -sinl;
+        irot = m - ll;
+        for (i=m - 1 ; i>=ll + 2 ; i+=-1) {
+          dlartg( f, g, &cosr, &sinr, &r );
+          e_1( i ) = r;
+          f = cosr*d_1( i ) + sinr*e_1( i-1 );
+          e_1( i-1 ) = cosr*e_1( i-1 ) - sinr*d_1( i );
+          g = sinr*d_1( i-1 );
+          d_1( i-1 ) = cosr*d_1( i-1 );
+          dlartg( f, g, &cosl, &sinl, &r );
+          d_1( i ) = r;
+          f = cosl*e_1( i-1 ) + sinl*d_1( i-1 );
+          d_1( i-1 ) = cosl*d_1( i-1 ) - sinl*e_1( i-1 );
+          g = sinl*e_1( i-2 );
+          e_1( i-2 ) = cosl*e_1( i-2 );
+          irot = irot - 1;
+          work_1( irot ) = cosr;
+          work_1( irot+nm1 ) = -sinr;
+          work_1( irot+nm12 ) = cosl;
+          work_1( irot+nm13 ) = -sinl;
+        }
+        dlartg( f, g, &cosr, &sinr, &r );
+        e_1( ll+1 ) = r;
+        f = cosr*d_1( ll+1 ) + sinr*e_1( ll );
+        e_1( ll ) = cosr*e_1( ll ) - sinr*d_1( ll+1 );
+        g = sinr*d_1( ll );
+        d_1( ll ) = cosr*d_1( ll );
+        dlartg( f, g, &cosl, &sinl, &r );
+        d_1( ll+1 ) = r;
+        f = cosl*e_1( ll ) + sinl*d_1( ll );
+        d_1( ll ) = cosl*d_1( ll ) - sinl*e_1( ll );
+        irot = irot - 1;
+        work_1( irot ) = cosr;
+        work_1( irot+nm1 ) = -sinr;
+        work_1( irot+nm12 ) = cosl;
+        work_1( irot+nm13 ) = -sinl;
+        e_1( ll ) = f;
 
       } else {
 
-	dlartg( f, g, &cosr, &sinr, &r );
-	f = cosr*d_1( m ) + sinr*e_1( m-1 );
-	e_1( m-1 ) = cosr*e_1( m-1 ) - sinr*d_1( m );
-	g = sinr*d_1( m-1 );
-	d_1( m-1 ) = cosr*d_1( m-1 );
-	dlartg( f, g, &cosl, &sinl, &r );
-	d_1( m ) = r;
-	f = cosl*e_1( m-1 ) + sinl*d_1( m-1 );
-	d_1( m-1 ) = cosl*d_1( m-1 ) - sinl*e_1( m-1 );
-	g = sinl*e_1( m-2 );
-	e_1( m-2 ) = cosl*e_1( m-2 );
-	for (i=m - 1 ; i>=ll + 2 ; i+=-1) {
-	  dlartg( f, g, &cosr, &sinr, &r );
-	  e_1( i ) = r;
-	  f = cosr*d_1( i ) + sinr*e_1( i-1 );
-	  e_1( i-1 ) = cosr*e_1( i-1 ) - sinr*d_1( i );
-	  g = sinr*d_1( i-1 );
-	  d_1( i-1 ) = cosr*d_1( i-1 );
-	  dlartg( f, g, &cosl, &sinl, &r );
-	  d_1( i ) = r;
-	  f = cosl*e_1( i-1 ) + sinl*d_1( i-1 );
-	  d_1( i-1 ) = cosl*d_1( i-1 ) - sinl*e_1( i-1 );
-	  g = sinl*e_1( i-2 );
-	  e_1( i-2 ) = cosl*e_1( i-2 );
-	}
-	dlartg( f, g, &cosr, &sinr, &r );
-	e_1( ll+1 ) = r;
-	f = cosr*d_1( ll+1 ) + sinr*e_1( ll );
-	e_1( ll ) = cosr*e_1( ll ) - sinr*d_1( ll+1 );
-	g = sinr*d_1( ll );
-	d_1( ll ) = cosr*d_1( ll );
-	dlartg( f, g, &cosl, &sinl, &r );
-	d_1( ll+1 ) = r;
-	f = cosl*e_1( ll ) + sinl*d_1( ll );
-	d_1( ll ) = cosl*d_1( ll ) - sinl*e_1( ll );
-	e_1( ll ) = f;
+        dlartg( f, g, &cosr, &sinr, &r );
+        f = cosr*d_1( m ) + sinr*e_1( m-1 );
+        e_1( m-1 ) = cosr*e_1( m-1 ) - sinr*d_1( m );
+        g = sinr*d_1( m-1 );
+        d_1( m-1 ) = cosr*d_1( m-1 );
+        dlartg( f, g, &cosl, &sinl, &r );
+        d_1( m ) = r;
+        f = cosl*e_1( m-1 ) + sinl*d_1( m-1 );
+        d_1( m-1 ) = cosl*d_1( m-1 ) - sinl*e_1( m-1 );
+        g = sinl*e_1( m-2 );
+        e_1( m-2 ) = cosl*e_1( m-2 );
+        for (i=m - 1 ; i>=ll + 2 ; i+=-1) {
+          dlartg( f, g, &cosr, &sinr, &r );
+          e_1( i ) = r;
+          f = cosr*d_1( i ) + sinr*e_1( i-1 );
+          e_1( i-1 ) = cosr*e_1( i-1 ) - sinr*d_1( i );
+          g = sinr*d_1( i-1 );
+          d_1( i-1 ) = cosr*d_1( i-1 );
+          dlartg( f, g, &cosl, &sinl, &r );
+          d_1( i ) = r;
+          f = cosl*e_1( i-1 ) + sinl*d_1( i-1 );
+          d_1( i-1 ) = cosl*d_1( i-1 ) - sinl*e_1( i-1 );
+          g = sinl*e_1( i-2 );
+          e_1( i-2 ) = cosl*e_1( i-2 );
+        }
+        dlartg( f, g, &cosr, &sinr, &r );
+        e_1( ll+1 ) = r;
+        f = cosr*d_1( ll+1 ) + sinr*e_1( ll );
+        e_1( ll ) = cosr*e_1( ll ) - sinr*d_1( ll+1 );
+        g = sinr*d_1( ll );
+        d_1( ll ) = cosr*d_1( ll );
+        dlartg( f, g, &cosl, &sinl, &r );
+        d_1( ll+1 ) = r;
+        f = cosl*e_1( ll ) + sinl*d_1( ll );
+        d_1( ll ) = cosl*d_1( ll ) - sinl*e_1( ll );
+        e_1( ll ) = f;
 
       }
       /**
        *           Test convergence
        **/
       if( abs( e_1( ll ) )<=thresh )
-	e_1( ll ) = zero;
+        e_1( ll ) = zero;
       /**
        *           Update singular vectors if desired
        **/
       if( ncvt>0 )
-	dlasr( 'l', 'v', 'b', m-ll+1, ncvt, &work_1( nm12+1 ),
-	      &work_1( nm13+1 ), &vt_2( ll, 1 ), ldvt );
+        dlasr( 'l', 'v', 'b', m-ll+1, ncvt, &work_1( nm12+1 ),
+              &work_1( nm13+1 ), &vt_2( ll, 1 ), ldvt );
       if( nru>0 )
-	dlasr( 'r', 'v', 'b', nru, m-ll+1, &work_1( 1 ),
-	      &work_1( n ), &u_2( 1, ll ), ldu );
+        dlasr( 'r', 'v', 'b', nru, m-ll+1, &work_1( 1 ),
+              &work_1( n ), &u_2( 1, ll ), ldu );
       if( ncc>0 )
-	dlasr( 'l', 'v', 'b', m-ll+1, ncc, &work_1( 1 ),
-	      &work_1( n ), &c_2( ll, 1 ), ldc );
+        dlasr( 'l', 'v', 'b', m-ll+1, ncc, &work_1( 1 ),
+              &work_1( n ), &c_2( ll, 1 ), ldc );
     }
   }
   /**
@@ -984,7 +981,7 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
        *           Change sign of singular vectors, if desired
        **/
       if( ncvt>0 )
-	ydscal( ncvt, negone, &vt_2( i, 1 ), ldvt );
+        cblas_dscal( ncvt, negone, &vt_2( i, 1 ), ldvt );
     }
   }
   /**
@@ -999,8 +996,8 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
     smin = d_1( 1 );
     for (j=2 ; j<=n + 1 - i ; j+=1) {
       if( d_1( j )<=smin ) {
-	isub = j;
-	smin = d_1( j );
+        isub = j;
+        smin = d_1( j );
       }
     }
     if( isub!=n+1-i ) {
@@ -1010,12 +1007,12 @@ void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
       d_1( isub ) = d_1( n+1-i );
       d_1( n+1-i ) = smin;
       if( ncvt>0 )
-	ydswap( ncvt, &vt_2( isub, 1 ), ldvt, &vt_2( n+1-i, 1 ),
-	      ldvt );
+        cblas_dswap( ncvt, &vt_2( isub, 1 ), ldvt, &vt_2( n+1-i, 1 ),
+              ldvt );
       if( nru>0 )
-	ydswap( nru, &u_2( 1, isub ), 1, &u_2( 1, n+1-i ), 1 );
+        cblas_dswap( nru, &u_2( 1, isub ), 1, &u_2( 1, n+1-i ), 1 );
       if( ncc>0 )
-	ydswap( ncc, &c_2( isub, 1 ), ldc, &c_2( n+1-i, 1 ), ldc );
+        cblas_dswap( ncc, &c_2( isub, 1 ), ldc, &c_2( n+1-i, 1 ), ldc );
     }
   }
   goto L_250;
