@@ -215,7 +215,7 @@ void Y_open(int nArgs)
     /* fail silently if optional errmode flag is set */
     p_free(fullname);
     permissions= 0;
-    PushDataBlock(Ref(&nilDB));
+    PushDataBlock(RefNC(&nilDB));
 
   } else {
     /* blow up if optional errmode flag is not set */
@@ -247,7 +247,7 @@ void Y_close(int nArgs)
         (s->value.db->ops==&textOps || s->value.db->ops==&streamOps)) {
       s->ops= &intScalar;
       Unref(s->value.db);
-      s->value.db= Ref(&nilDB);
+      s->value.db= RefNC(&nilDB);
       s->ops= &dataBlockSym;
     }
   }
@@ -818,29 +818,27 @@ WriteWorker(Operand *sinkOp, Symbol *stack, char *format)
     if (!sinkOp) {
       result->value.q[i]= p_strcpy(outBuf);
     } else {
-      /* YPrompt does NOT append \n, as desired (YputsOut does) */
-      if (i && ((nArgs>nConversions && nArgs>1) || nLine>lineSize)) {
-        if (sinkOp->ops) {
-          if (file) p_fputs(file, "\n");
-          else p_stdout("\n");
-        } else YPrompt("\n");
+      /* extra line break explained in help,write documentation
+       * nLine>nChars not mentioned in documentation prevents
+       * extra line break if single argument is longer than lineSize
+       */
+      if (i && ((nArgs>nConversions && nArgs>1) ||
+                (nLine>lineSize && nLine>nChars))) {
+        if (sinkOp->ops && file) p_fputs(file, "\n");
+        else p_stdout("\n");
         fmtTotal++;
         nLine= strlen(outBuf);
       }
-      if (sinkOp->ops) {
-        if (file) p_fputs(file, outBuf);
-        else p_stdout(outBuf);
-      } else YPrompt(outBuf);
+      if (sinkOp->ops && file) p_fputs(file, outBuf);
+      else p_stdout(outBuf);
       if (nChars && text[-1]=='\n') nLine= 0;
     }
   }
 
   /* add trailing newline if it seems reasonable to do so */
   if (sinkOp && nArgs>nConversions) {
-    if (sinkOp->ops) {
-      if (file) p_fputs(file, "\n");
-      else p_stdout("\n");
-    } else YPrompt("\n");
+    if (sinkOp->ops && file) p_fputs(file, "\n");
+    else p_stdout("\n");
     fmtTotal++;
   }
 
@@ -861,7 +859,7 @@ IOFileLink *yTextFiles= 0;
    at a time.  Since TextStream contains several pointers, the alignment
    of an TextStream must be at least as strict as a void*.  */
 static MemryBlock txtsBlock= {0, 0, sizeof(TextStream),
-                                  16*sizeof(TextStream)};
+                              16*sizeof(TextStream)};
 
 TextStream *NewTextStream(char *fullname, void *stream, int permissions,
                           long line, long pos)
